# Impacts
### On this page
  * [Implied and Custom Impacts of Transformations](https://help.sap.com/docs/leanix/ea/impacts#implied-and-custom-impacts-of-transformations)
  * [Impacts Execution Order](https://help.sap.com/docs/leanix/ea/impacts#impacts-execution-order)
  * [Impact Type Classification Rules](https://help.sap.com/docs/leanix/ea/impacts#impact-type-classification-rules)


Impacts detail the changes at attribute and relation levels. Learn how to manage these Impacts in SAP LeanIX Architecture and Road Map Planning.
**Note**
SAP LeanIX Architecture and Road Map Planning was previously known as Business Transformation Module (BTM).
When Transformations are outlined in the Initiative Fact Sheet, SAP LeanIX Architecture and Road Map Planning automatically deconstructs them into Implied Impacts, specifying changes at attribute and relation levels. This involves actions such as setting a field with a specific value, creating or removing relations, copying or moving values between Fact Sheets, etc. These implied impacts are further translated and classified as an Impact Type, providing a basis for visualization in Reports.
The following Impact Types are available:
  * Introduction - An application is introduced into the landscape.
  * Decommissioning - An application is decommissioned.
  * Rollout - An application is rolled out to a selection of organizations or regions.
  * Withdrawal - An application is withdrawn from a selection of organizations or regions.
  * Scope Change - The scope of the Application is changed with respect to certain business capabilities, or data objects.
  * Technical Change - The IT component of the application is changed.
  * Interface Change - Change in interfaces of application.
  * Discontinuation - An application or interface is discontinued.


The Impact Type Classification introduces a new View in reports. For example, in an Application Landscape Report, you can see how various applications are impacted because of an Initiative.
![Impact type view in reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275247ab7a4410149791e006e4168113_LowRes.gif)
Impact type view in reports
The Impact Type also opens up new filtering options, allowing you to filter, for instance, all applications set to be introduced by a specific project or all projects planning an Application Rollout in the upcoming year, etc.
![Impact Type filtering options](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27462e637a441014a296b545de888c27_LowRes.png)
Impact Type filtering options
